@@ -1,4 +1,5 @@
 ### R code from vignette source 'summarizeOverlaps.Rnw'
+### Encoding: UTF-8
 
 ###################################################
 ### code chunk number 1: style
@@ -18,7 +19,7 @@ options("showTailLines" = 3)
 ### code chunk number 3: firstExample
 ###################################################
 library(GenomicAlignments)
-library(DESeq)
+library(DESeq2)
 library(edgeR)
 
 fls <- list.files(system.file("extdata", package="GenomicAlignments"),
@@ -32,7 +33,7 @@ features <- GRanges(
     group_id=c(rep("A", 4), rep("B", 5), rep("C", 2)))
 
 olap <- summarizeOverlaps(features, fls)
-deseq <- newCountDataSet(assay(olap), rownames(colData(olap)))
+deseq <- DESeqDataSet(olap, design= ~ 1)
 edger <- DGEList(assay(olap), group=rownames(colData(olap)))
 
 
@@ -164,7 +165,7 @@ param <- ScanBamParam(
 ###################################################
 ### code chunk number 15: pasilla_exoncountset (eval = FALSE)
 ###################################################
-## expdata = MIAME(
+## expdata <- MIAME(
 ##               name="pasilla knockdown",
 ##               lab="Genetics and Developmental Biology, University of 
 ##                   Connecticut Health Center",
@@ -184,12 +185,7 @@ param <- ScanBamParam(
 ##               type=rep("single-read", 3),
 ##               countfiles=path(colData(genehits)[,1]), stringsAsFactors=TRUE)
 ## 
-## geneCDS <- newCountDataSet(
-##                   countData=assay(genehits),
-##                   conditions=design)
-## 
-## experimentData(geneCDS) <- expdata
-## sampleNames(geneCDS) = colnames(genehits)
+## geneCDS <- DESeqDataSet(genehits, design=design, metadata=list(expdata=expdata))
 
 
 ###################################################
@@ -197,7 +193,6 @@ param <- ScanBamParam(
 ###################################################
 ## chr4tx <- split(gff, mcols(gff)$transcript_id)
 ## txhits <- summarizeOverlaps(chr4tx, bamlst)
-## txCDS <- newCountDataSet(assay(txhits), design) 
-## experimentData(txCDS) <- expdata
+## txCDS <- DESeqDataSet(txhits, design=design, metadata=list(expdata=expdata))
 
 
